classNameKey = 'className'
methodNameKey = 'methodName'
preHookKey = 'preHook'
postHookKey = 'postHook'

AGENT_VERSION = '1.0.0'
NEXTAPM_HOST = 'NEXTAPM_HOST'
NEXTAPM_LICENSE_KEY = 'NEXTAPM_LICENSE_KEY'
NEXTAPM_PROJECT_ID = 'NEXTAPM_PROJECT_ID'
DEFAULT_COLLECTOR = 'https://data.nextapm.dev'

